@@ -1,7 +1,7 @@
 import logging
 import os
 
-from django.db import transaction
+from django.db import transaction, IntegrityError
 
 from isc_common import setAttr
 from isc_common.common.functions import delete_dbl_spaces
@@ -9,6 +9,7 @@ from kaf_pas.kd.models.document_attributes_view import Document_attributes_view
 
 logger = logging.getLogger(__name__)
 
+
 class DocumentManagerExt:
 
     def __init__(self, logger):
@@ -100,9 +101,11 @@ class DocumentManagerExt:
 
                     parent_count = 0
                     parent = None
+                    cnt = 0
                     for item in item_query:
                         parent_count = Item_refs.objects.filter(parent=item).count()
                         parent = item
+                        cnt += 1
                         if parent_count > 0:
                             break
 
@@ -112,7 +115,7 @@ class DocumentManagerExt:
                             STMP_2_id=STMP_2.id if STMP_2 else None,
                             props=props,
                             document=document,
-                            version=ItemManager.get_verstion(STMP_1=STMP_1, STMP_2=STMP_2, props=Item.props.from_spw)
+                            version=ItemManager.get_verstion(STMP_1=STMP_1, STMP_2=STMP_2, props=Item.props.from_spw) if cnt != 0 else None
                         )
 
                         Item_refs.objects.create(parent_id=int(top_level.value), child=parent)
@@ -235,7 +238,6 @@ class DocumentManagerExt:
         from kaf_pas.kd.models.documents import Documents
         from kaf_pas.system.models.contants import Contants
         from kaf_pas.ckk.models.item import ItemManager
-        from kaf_pas.ckk.models.item_document import Item_document
 
         top_level = Contants.objects.get(code='audo_top_level')
 
@@ -253,29 +255,31 @@ class DocumentManagerExt:
                     STMP_2 = None
 
                 if STMP_1 != None or STMP_2 != None:
-                    cnt = 0
+                    cnt = Item.objects.filter(
+                        STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1.value_str) if STMP_1 else None,
+                        STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2.value_str) if STMP_2 else None,
+                        props=Item.props.relevant | Item.props.from_cdw,
+                    ).count()
 
-                    for item in Item.objects.filter(
-                            STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1.value_str) if STMP_1 else None,
-                            STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2.value_str) if STMP_2 else None,
-                            props=Item.props.relevant | Item.props.from_cdw,
-                    ):
-                        self.link_image_to_item(item)
-                        Item_refs.objects.get_or_create(parent_id=int(top_level.value), child=item)
-                        Item_document.objects.get_or_create(item=item, document=document)
-                        cnt += 1
+                    version = None
+                    if cnt != 0:
+                        version = ItemManager.get_verstion(STMP_1=STMP_1, STMP_2=STMP_2, props=Item.props.relevant | Item.props.from_cdw)
 
-                    if cnt == 0:
-                        item = Item.objects.create(
-                            STMP_1_id=STMP_1.id if STMP_1 else None,
-                            STMP_2_id=STMP_2.id if STMP_2 else None,
-                            props=Item.props.relevant | Item.props.from_cdw,
-                            document=document,
-                            version=ItemManager.get_verstion(STMP_1=STMP_1, STMP_2=STMP_2, props=Item.props.from_cdw)
-                        )
+                    while True:
+                        try:
+                            item = Item.objects.create(
+                                STMP_1_id=STMP_1.id if STMP_1 else None,
+                                STMP_2_id=STMP_2.id if STMP_2 else None,
+                                props=Item.props.relevant | Item.props.from_cdw,
+                                document=document,
+                                version=version
+                            )
+                            break
+                        except IntegrityError:
+                            version += 1
 
-                        Item_refs.objects.get_or_create(parent_id=int(top_level.value), child=item)
-                        self.link_image_to_item(item)
+                    Item_refs.objects.get_or_create(parent_id=int(top_level.value), child=item)
+                    self.link_image_to_item(item)
 
                 else:
                     pass
@@ -286,7 +290,6 @@ class DocumentManagerExt:
     def make_pdf(self, document, STMP_1_type, STMP_2_type):
         from kaf_pas.ckk.models.item import Item
         from kaf_pas.ckk.models.item import ItemManager
-        from kaf_pas.ckk.models.item_document import Item_document
         from kaf_pas.ckk.models.item_refs import Item_refs
         from kaf_pas.kd.models.document_attributes import Document_attributes
         from kaf_pas.kd.models.documents import Documents
@@ -310,29 +313,31 @@ class DocumentManagerExt:
                 STMP_1_attr, _ = Document_attributes.objects.get_or_create(value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1), attr_type=STMP_1_type)
                 STMP_2_attr, _ = Document_attributes.objects.get_or_create(value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2), attr_type=STMP_2_type)
 
-                cnt = 0
+                cnt = Item.objects.filter(
+                    STMP_1__value_str__delete_dbl_spaces=STMP_1,
+                    STMP_2__value_str__delete_dbl_spaces=STMP_2,
+                    props=Item.props.relevant | Item.props.from_pdf,
+                ).count()
 
-                for item in Item.objects.filter(
-                        STMP_1__value_str__delete_dbl_spaces=STMP_1,
-                        STMP_2__value_str__delete_dbl_spaces=STMP_2,
-                        props=Item.props.relevant | Item.props.from_pdf,
-                ):
-                    self.link_image_to_item(item)
-                    Item_refs.objects.get_or_create(parent_id=int(top_level.value), child=item)
-                    Item_document.objects.get_or_create(item=item, document=document)
-                    cnt += 1
+                version = None
+                if cnt != 0:
+                    version = ItemManager.get_verstion(STMP_1=STMP_1_attr, STMP_2=STMP_2_attr, props=Item.props.from_pdf)
 
-                if cnt == 0:
-                    item = Item.objects.create(
-                        STMP_1_id=STMP_1_attr,
-                        STMP_2_id=STMP_2_attr,
-                        props=Item.props.relevant | Item.props.from_pdf,
-                        document=document,
-                        version=ItemManager.get_verstion(STMP_1=STMP_1_attr, STMP_2=STMP_2_attr, props=Item.props.from_pdf)
-                    )
+                while True:
+                    try:
+                        item = Item.objects.create(
+                            STMP_1_id=STMP_1_attr,
+                            STMP_2_id=STMP_2_attr,
+                            props=Item.props.relevant | Item.props.from_pdf,
+                            document=document,
+                            version=version
+                        )
+                        break
+                    except IntegrityError:
+                        version += 1
 
-                    Item_refs.objects.get_or_create(parent_id=int(top_level.value), child=item)
-                    self.link_image_to_item(item)
+                Item_refs.objects.get_or_create(parent_id=int(top_level.value), child=item)
+                self.link_image_to_item(item)
 
             document.props |= Documents.props.beenItemed
             document.save()
