@@ -86,7 +86,6 @@ class Lotsman_documents_hierarcyManager(AuditManager):
     def getRecord(record):
         res = {
             'id': record.id,
-            'parent': record.parent.id if record.parent else None,
             'editing': record.editing,
             'deliting': record.deliting,
         }
@@ -138,7 +137,7 @@ class Lotsman_documents_hierarcy(AuditModel):
     objects = Lotsman_documents_hierarcyManager()
 
     def __str__(self):
-        return f'ID:{self.id}, attr_type: {self.attr_type}, document: {self.document}, props: {self.props}'
+        return f'ID:{self.id}, attr_type: [{self.attr_type}], document: [{self.document}], props: {self.props}'
 
     def __repr__(self):
         return self.__str__()
