@@ -1,4 +1,5 @@
 import logging
+import sys
 from datetime import datetime
 
 from django.conf import settings
@@ -65,7 +66,6 @@ class Production_order_valuesManager(OperationsManager):
 
             return res
 
-    # todo Общий метод проверки при изменении колияечтва выполненных операций
     # IUD - Insert/Update/Delete
     @staticmethod
     def makeAll(parent, childs, value, opertype, edizm, user):
@@ -82,11 +82,8 @@ class Production_order_valuesManager(OperationsManager):
         # value количетвенная операция данной производственной операции
         # opertype - тип REST операции "add", "update" etc
 
-        # todo Автоматические обновления соответствующих гридов
-        # todo Проверка на добустимость колличества (наличие)
-        # todo Проверка на кол-во полных циклов операций для выпуска изделия
-
         res = []
+        settings.LOCKS.acquire('Production_order_valuesManager.makeAll')
         if opertype == 'add':
 
             # Определяем позволяет ли остатки в операциях записать их как сделанные
@@ -131,7 +128,7 @@ class Production_order_valuesManager(OperationsManager):
                     opertype=settings.OPERS_TYPES_STACK.MADE_OPERATIONS_TASK
                 )
 
-            min_qty_release = 0
+            min_qty_release = sys.maxsize
             production_order_detail_arr = []
             for production_order_detail in Production_order_detail.objects.filter(
                     parent_id=parent.id,
@@ -139,11 +136,11 @@ class Production_order_valuesManager(OperationsManager):
 
                 values_not_used_in_release_sum = values_not_used_in_release(id=production_order_detail.id).aggregate(Sum('value__value')).get('value__value__sum', 0)
                 if values_not_used_in_release_sum > 0:
-                    min_qty_release_prev = values_not_used_in_release_sum // production_order_detail.value.value
+                    min_qty_release_prev = values_not_used_in_release_sum // production_order_detail.value_per_one
                     if min_qty_release_prev == 0:
                         return res
                     else:
-                        if min_qty_release < min_qty_release_prev:
+                        if min_qty_release > min_qty_release_prev:
                             min_qty_release = min_qty_release_prev
                         production_order_detail_arr.append(production_order_detail)
 
@@ -220,7 +217,7 @@ class Production_order_valuesManager(OperationsManager):
                         )
 
             first_step = True
-            parent_release = True
+            parent_release = None
             for releases_det_operation in releases_det_operations:
                 if first_step:
                     parent_release = Operations.objects.create(
@@ -229,6 +226,8 @@ class Production_order_valuesManager(OperationsManager):
                         status=settings.OPERS_TYPES_STACK.RELEASE_TASK_PLUS.get('new'),
                         creator=user
                     )
+                    Operation_refs.objects.create(parent=parent, child=parent_release)
+                    Operation_value.objects.create(operation=parent_release, edizm=edizm, value=min_qty_release, props=Operation_value.props.used_in_release)
 
                     Operation_item.objects.create(
                         operation=parent_release,
@@ -237,10 +236,9 @@ class Production_order_valuesManager(OperationsManager):
                         item_full_name_obj=parent.item.full_name_obj
                     )
                     first_step = False
-                    Operation_value.objects.create(operation=parent_release, edizm=edizm, value=min_qty_release, props=Operation_value.props.used_in_release)
 
-                if parent_release != None:
-                    Operation_refs.objects.create(parent=parent_release, child=releases_det_operation)
+                Operation_refs.objects.create(parent=parent_release, child=releases_det_operation)
+        settings.LOCKS.release('Production_order_valuesManager.makeAll')
 
         return res
 
